@@ -93,7 +93,11 @@ class ChromiumBase(BasePage):
                 if self._debug_recorder:
                     self._debug_recorder.add_data((perf_counter(), '获取document', '开始'))
 
-            self._wait_loaded()
+            try:  # 处理标签页关闭的情况
+                self._wait_loaded()
+            except ConnectionError:
+                return
+
             while True:
                 try:
                     root_id = self._tab_obj.DOM.getDocument()['root']['nodeId']
@@ -168,6 +172,8 @@ class ChromiumBase(BasePage):
             if self._debug_recorder:
                 self._debug_recorder.add_data((perf_counter(), '加载流程', 'loadEventFired'))
 
+        self._get_document()
+
     def _onDocumentUpdated(self, **kwargs):
         """页面跳转时触发"""
         if self._debug:
@@ -177,10 +183,12 @@ class ChromiumBase(BasePage):
 
     def _onFrameNavigated(self, **kwargs):
         """页面跳转时触发"""
-        if self._debug and not kwargs['frame'].get('parentId', None):
-            print('navigated')
-            if self._debug_recorder:
-                self._debug_recorder.add_data((perf_counter(), '加载流程', 'navigated'))
+        if kwargs['frame'].get('parentId', None) == self.tab_id and self._first_run is False and self._is_loading:
+            self._is_loading = True
+            if self._debug:
+                print('navigated')
+                if self._debug_recorder:
+                    self._debug_recorder.add_data((perf_counter(), '加载流程', 'navigated'))
 
     def __call__(self, loc_or_str, timeout=None):
         """在内部查找元素
@@ -194,6 +202,7 @@ class ChromiumBase(BasePage):
     @property
     def title(self):
         """返回当前页面title"""
+        self._wait_loaded()
         return self._tab_obj.Target.getTargetInfo(targetId=self.tab_id)['targetInfo']['title']
 
     @property
@@ -221,11 +230,13 @@ class ChromiumBase(BasePage):
     @property
     def url(self):
         """返回当前页面url"""
+        self._wait_loaded()
         return self._tab_obj.Target.getTargetInfo(targetId=self.tab_id)['targetInfo']['url']
 
     @property
     def html(self):
         """返回当前页面html文本"""
+        self._wait_loaded()
         return self._wait_driver.DOM.getOuterHTML(objectId=self._root_id)['outerHTML']
 
     @property
@@ -244,14 +255,19 @@ class ChromiumBase(BasePage):
     @property
     def ready_state(self):
         """返回当前页面加载状态，'loading' 'interactive' 'complete'"""
-        return self._tab_obj.Runtime.evaluate(expression='document.readyState;')['result']['value']
+        try:
+            return self._tab_obj.Runtime.evaluate(expression='document.readyState;')['result']['value']
+        except KeyError:
+            raise ConnectionError('标签页或连接已关闭。')
 
     @property
     def size(self):
-        """返回页面总长高，格式：(长, 高)"""
-        w = self.run_js('document.body.scrollWidth;', as_expr=True)
-        h = self.run_js('document.body.scrollHeight;', as_expr=True)
-        return w, h
+        """返回页面总宽高，格式：(宽, 高)"""
+        # w = self.run_js('document.body.scrollWidth;', as_expr=True)
+        # h = self.run_js('document.body.scrollHeight;', as_expr=True)
+        # return w, h
+        r = self.run_cdp('Page.getLayoutMetrics', not_change=False)['contentSize']
+        return r['width'], r['height']
 
     @property
     def active_ele(self):
@@ -334,13 +350,13 @@ class ChromiumBase(BasePage):
                                               timeout=timeout)
         return self._url_available
 
-    def wait_loading(self, timeout=1):
+    def wait_loading(self, timeout=None):
         """阻塞程序，等待页面进入加载状态
         :param timeout: 超时时间
         :return: 等待结束时是否进入加载状态
         """
-        if timeout:
-            timeout = 2 if timeout is True else timeout
+        if timeout != 0:
+            timeout = self.timeout if timeout in (None, True) else timeout
             end_time = perf_counter() + timeout
             while perf_counter() < end_time:
                 if self.is_loading:
@@ -432,17 +448,20 @@ class ChromiumBase(BasePage):
 
         nodeIds = None
         end_time = perf_counter() + timeout
+        ok = False
         while True:
             if count > 0:
                 count = 1 if single else count
                 try:
                     nodeIds = self._wait_driver.DOM.getSearchResults(searchId=search_result['searchId'],
                                                                      fromIndex=0, toIndex=count)
-                    break
+                    if nodeIds['nodeIds'][0] != 0:
+                        ok = True
+
                 except Exception:
                     sleep(.01)
 
-            if perf_counter() >= end_time:
+            if ok or perf_counter() >= end_time:
                 break
 
             search_result = self._wait_driver.DOM.performSearch(query=loc, includeUserAgentShadowDOM=True)
@@ -557,12 +576,16 @@ class ChromiumBase(BasePage):
                 raise RuntimeError('该元素已不在当前页面中。')
             raise
 
-    def set_user_agent(self, ua):
+    def set_user_agent(self, ua, platform=None):
         """为当前tab设置user agent，只在当前tab有效
         :param ua: user agent字符串
+        :param platform: platform字符串
         :return: None
         """
-        self._wait_driver.Network.setUserAgentOverride(userAgent=ua)
+        keys = {'userAgent': ua}
+        if platform:
+            keys['platform'] = platform
+        self._wait_driver.Emulation.setUserAgentOverride(**keys)
 
     def get_session_storage(self, item=None):
         """获取sessionStorage信息，不设置item则获取全部
