@@ -52,7 +52,7 @@ class ChromiumPage(ChromiumBase):
         # 接收浏览器地址和端口
         elif isinstance(addr_driver_opts, str):
             self.address = addr_driver_opts
-            self._driver_options = ChromiumOptions(read_file=False)
+            self._driver_options = ChromiumOptions()
             self._driver_options.debugger_address = addr_driver_opts
             self.process = connect_browser(self._driver_options)[1]
             if not tab_id:
@@ -126,6 +126,11 @@ class ChromiumPage(ChromiumBase):
     def main_tab(self):
         return self._main_tab
 
+    @property
+    def latest_tab(self):
+        """返回最新的标签页id，最新标签页指最后创建或最后被激活的"""
+        return self.tabs[0]
+
     @property
     def process_id(self):
         """返回浏览器进程id"""
@@ -350,6 +355,7 @@ class ChromiumPage(ChromiumBase):
         :return: 提示框内容文本，未等到提示框则返回None
         """
         timeout = timeout or self.timeout
+        timeout = .1 if timeout <= 0 else timeout
         end_time = perf_counter() + timeout
         while not self._alert.activated and perf_counter() < end_time:
             sleep(.1)
